diff --git a/src/git-command-manager.ts b/src/git-command-manager.ts
index f4cb01c..0adc732 100644
--- a/src/git-command-manager.ts
+++ b/src/git-command-manager.ts
@@ -11,8 +11,8 @@ import {GitVersion} from './git-version'
 
 // Auth header not supported before 2.9
 // Wire protocol v2 not supported before 2.18
-// sparse-checkout not supported before 2.27
-export const MinimumGitVersion = new GitVersion('2.27')
+// sparse-checkout not supported before 2.25
+export const MinimumGitVersion = new GitVersion('2.25')
 
 export interface IGitCommandManager {
   branchDelete(remote: boolean, branch: string): Promise<void>